@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(gen_read_table_func);
 
 with 'SHARYANTO::Role::I18NMany';
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 our %SPEC;
 
@@ -97,7 +97,8 @@ sub _gen_meta {
 
     my $func_meta = {
         v => 1.1,
-        summary => "REPLACE ME",
+        summary => $opts->{summary} // $table_spec->{summary} // "REPLACE ME",
+        description => "REPLACE ME",
         args => {},
     };
     my $func_args = $func_meta->{args};
@@ -835,6 +836,14 @@ arguments.
 
 _
     args => {
+        summary => {
+            summary => "Generated function's summary",
+            schema => 'str*',
+        },
+        description => {
+            summary => "Generated function's description",
+            schema => 'str*',
+        },
         table_data => {
             req => 1,
             schema => 'any*',
@@ -1052,6 +1061,8 @@ sub _gen_read_table_func {
 
     my $dav = $args{default_arg_values} // {};
     my $opts = {
+        summary                    => $args{summary},
+        description                => $args{description},
         langs                      => $args{langs} // ['en_US'],
         default_detail             => $args{default_detail},
         default_with_field_names   => $args{default_with_field_names},
@@ -1094,7 +1105,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its Rinci metadata) to a
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -1116,8 +1127,10 @@ In list_countries.pl:
  ];
 
  my $res = gen_read_table_func(
-     table_data => $countries,
-     table_spec => {
+     summary     => 'func summary',     # opt
+     description => 'func description', # opt
+     table_data  => $countries,
+     table_spec  => {
          summary => 'List of countries',
          fields => {
              id => {
@@ -1428,6 +1441,10 @@ Supply default 'sort' value in generated function's metadata.
 
 Supply default 'with_field_names' value in generated function's metadata.
 
+=item * B<description>* => I<str>
+
+Generated function's description.
+
 =item * B<enable_search> => I<bool> (default: 1)
 
 Decide whether generated function will support searching (argument q).
@@ -1453,6 +1470,10 @@ metadata might look something like this:
         ...
     }
 
+=item * B<summary>* => I<str>
+
+Generated function's summary.
+
 =item * B<table_data>* => I<any>
 
 Data.
